#!/bin/bash
syntax_errors=0
error_msg=$(mktemp /tmp/error_msg.XXXXXX)

git rev-parse --quiet --verify HEAD > /dev/null
if [ $? -eq 0 ]; then
  against=HEAD
else
  # Initial commit: diff against an empty tree object 
  against=4b825dc642cb6eb9a060e54bf8d69288fbee4904
fi

# Get list of new/modified manifest and template files to check (in git index) 
for indexfile in $(git diff-index --diff-filter=AM --name-only --cached $against | egrep '\.(pp|erb)')
do
  # Don't check empty files 
  if [ $(git cat-file -s :0:$indexfile) -gt 0 ]; then
    case $indexfile in
    *.pp )
      # Check puppet manifest syntax 
      git cat-file blob :0:$indexfile | puppet parser validate 2>$error_msg ;;
    *.erb )
      # Check ERB template syntax 
      git cat-file blob :0:$indexfile | erb -x -T - | ruby -c 2>$error_msg >/dev/null ;;
    esac
    if [ "$?" -ne 0 ]; then
      echo -n "$indexfile: "
      cat $error_msg
      syntax_errors=$((syntax_errors + 1))
    fi
  fi
done
rm -f $error_msg
if [ "$syntax_errors" -ne 0 ]; then
  if [ "$syntax_errors" -gt 1 ]; then
    echo "Error: $syntax_errors syntax errors found, aborting commit."
  else
    echo "Error: 1 syntax error found, aborting commit."
  fi
  exit 1
fi
